@@ -345,10 +345,10 @@ netk_screen_construct (NetkScreen * screen, int number)
  * Return value: the #NetkScreen for screen @index
  **/
 NetkScreen *
-netk_screen_get (int index)
+netk_screen_get (int idx)
 {
     g_return_val_if_fail (gdk_display != NULL, NULL);
-    g_return_val_if_fail (index < ScreenCount (gdk_display), NULL);
+    g_return_val_if_fail (idx < ScreenCount (gdk_display), NULL);
 
     if (screens == NULL)
     {
@@ -356,16 +356,17 @@ netk_screen_get (int index)
         p_netk_event_filter_init ();
     }
 
-    if (screens[index] == NULL)
+    if (screens[idx] == NULL)
     {
-        screens[index] = g_object_new (NETK_TYPE_SCREEN, NULL);
+        screens[idx] = g_object_new (NETK_TYPE_SCREEN, NULL);
 
-        netk_screen_construct (screens[index], index);
+        netk_screen_construct (screens[idx], idx);
     }
 
-    return screens[index];
+    return screens[idx];
 }
 
+#if 0
 NetkScreen *
 p_netk_screen_get_existing (int number)
 {
@@ -377,6 +378,7 @@ p_netk_screen_get_existing (int number)
     else
         return NULL;
 }
+#endif
 
 NetkScreen *
 netk_screen_get_default (void)
@@ -1216,14 +1218,14 @@ update_viewport_settings (NetkScreen * screen)
                 space = netk_screen_get_workspace (screen, i);
                 g_assert (space != NULL);
 
-                if (p_coord[x] < 0)
+                if ((gint)p_coord[x] < 0)
                     p_coord[x] = 0;
-                else if (p_coord[x] > space_width - screen_width)
+                else if ((int) p_coord[x] > space_width - screen_width)
                     p_coord[x] = space_width - screen_width;
 
-                if (p_coord[y] < 0)
+                if ((gint)p_coord[y] < 0)
                     p_coord[y] = 0;
-                else if (p_coord[y] > space_height - screen_height)
+                else if ((int) p_coord[y] > space_height - screen_height)
                     p_coord[y] = space_height - screen_height;
 
                 if (p_netk_workspace_set_viewport (space,
