@@ -918,7 +918,7 @@ xfce_file_chooser_remove_shortcut_folder(XfceFileChooser *chooser,
  * Return value: An #XfceFileFilter, or %NULL (GTK+ 2.2 and below).
  **/
 XfceFileFilter *
-xfce_file_filter_new()
+xfce_file_filter_new(void)
 {
 #if GTK_CHECK_VERSION(2, 4, 0)
 	return GTK_OBJECT(gtk_file_filter_new());
