@@ -1,4 +1,4 @@
-/* $Id: xfce-gtk-extensions.h,v 1.1 2004/06/14 17:54:31 benny Exp $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2004 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -22,6 +22,8 @@
 #ifndef __XFCE_GTK_EXTENSIONS_H__
 #define __XFCE_GTK_EXTENSIONS_H__
 
+#if defined(LIBXFCEGUI4_COMPILATION) || !defined(XFCE_DISABLE_DEPRECATED)
+
 #include <gtk/gtk.h>
 
 G_BEGIN_DECLS;
@@ -34,5 +36,7 @@ void xfce_gtk_window_center_on_monitor_with_pointer (GtkWindow *window);
 
 G_END_DECLS;
 
+#endif /* !XFCE_DISABLE_DEPRECATED */
+
 #endif /* !__XFCE_GTK_EXTENSIONS_H__ */
 
