@@ -72,8 +72,6 @@ struct message
 };
 
 /* prototypes */
-static void xfce_system_tray_init (XfceSystemTray *);
-static void xfce_system_tray_class_init (XfceSystemTrayClass *);
 static void xfce_system_tray_finalize (GObject *);
 static void xfce_system_tray_dock_request (XClientMessageEvent *,
                                            XfceSystemTray *);
@@ -86,8 +84,6 @@ xfce_system_tray_opcode (XfceSystemTray *tray, GdkXEvent * xevent);
 static GdkFilterReturn
 xfce_system_tray_filter (GdkXEvent *xev, GdkEvent *event, gpointer data);
 
-/* */
-static GObjectClass *parent_class;
 
 /* */
 static guint tray_signals[LAST_SIGNAL];
@@ -105,34 +101,8 @@ xfce_system_tray_error_quark (void)
     return (quark);
 }
 
-GType
-xfce_system_tray_get_type (void)
-{
-    static GType xfce_system_tray_type = 0;
 
-    if (!xfce_system_tray_type)
-    {
-        static const GTypeInfo xfce_system_tray_info = {
-            sizeof (XfceSystemTrayClass),
-            NULL,		/* base_init */
-            NULL,		/* base_finalize */
-            (GClassInitFunc) xfce_system_tray_class_init,
-            NULL,		/* class_finalize */
-            NULL,		/* class_data */
-            sizeof (XfceSystemTray),
-            0,			/* n_preallocs */
-            (GInstanceInitFunc) xfce_system_tray_init,
-            NULL		/* value_table */
-        };
-
-        xfce_system_tray_type = g_type_register_static (G_TYPE_OBJECT,
-                                                        "XfceSystemTray",
-                                                        &xfce_system_tray_info,
-                                                        0);
-    }
-
-    return (xfce_system_tray_type);
-}
+G_DEFINE_TYPE (XfceSystemTray, xfce_system_tray, G_TYPE_OBJECT)
 
 static void
 xfce_system_tray_class_init (XfceSystemTrayClass * klass)
@@ -142,8 +112,6 @@ xfce_system_tray_class_init (XfceSystemTrayClass * klass)
     /* be sure to initialize the libraries i18n support first */
     _xfce_i18n_init ();
 
-    parent_class = g_type_class_peek_parent (klass);
-
     gobject_class = G_OBJECT_CLASS (klass);
     gobject_class->finalize = xfce_system_tray_finalize;
 
@@ -222,7 +190,7 @@ xfce_system_tray_finalize (GObject * object)
     g_list_free (tray->messages);
     g_hash_table_destroy (tray->sockets);
 
-    G_OBJECT_CLASS (parent_class)->finalize (object);
+    G_OBJECT_CLASS (xfce_system_tray_parent_class)->finalize (object);
 }
 
 
